@@ -2,6 +2,9 @@
 //
 // Copyright Bob Friesenhahn, 1999, 2000, 2001, 2002
 //
+// Copyright @ 2014 ImageMagick Studio LLC, a non-profit organization
+// dedicated to making software imaging solutions freely available.
+//
 // Blob reference class
 //
 // This is an internal implementation class that should not be
@@ -20,22 +23,29 @@ namespace Magick
   class BlobRef
   {
   public:
+
     // Construct with data, making private copy of data
-    BlobRef(const void* data_,size_t length_);
+    BlobRef(const void* data_,const size_t length_);
 
     // Destructor (actually destroys data)
     ~BlobRef(void);
 
-    void*           _data;      // Blob data
-    size_t          _length;    // Blob length
-    Blob::Allocator _allocator; // Memory allocation system in use
-    ::ssize_t       _refCount;  // Reference count
-    MutexLock       _mutexLock; // Mutex lock
+    // Decreases reference count and return the new count
+    size_t decrease();
+
+    // Increases reference count
+    void increase();
+
+    Blob::Allocator allocator; // Memory allocation system in use
+    size_t          length;    // Blob length
+    void*           data;      // Blob data
 
   private:
     // Copy constructor and assignment are not supported
     BlobRef(const BlobRef&);
-    BlobRef& operator=(const BlobRef&);
+
+    MutexLock _mutexLock; // Mutex lock
+    size_t    _refCount;  // Reference count
   };
 
 } // namespace Magick
