@@ -2,6 +2,9 @@
 //
 // Copyright Bob Friesenhahn, 2001, 2002
 //
+// Copyright @ 2014 ImageMagick Studio LLC, a non-profit organization
+// dedicated to making software imaging solutions freely available.
+//
 // TypeMetric Definition
 //
 // Container for font type metrics
@@ -11,6 +14,7 @@
 #define Magick_TypeMetric_header
 
 #include "Magick++/Include.h"
+#include "Magick++/Drawable.h"
 
 namespace Magick
 {
@@ -26,18 +30,26 @@ namespace Magick
     // Destructor
     ~TypeMetric(void);
 
-    // Ascent, the distance in pixels from the text baseline to the
-    // highest/upper grid coordinate used to place an outline point.
+    // The distance in pixels from the text baseline to the highest/upper
+    // grid coordinate used to place an outline point.
     double ascent(void) const;
 
-    // Descent, the distance in pixels from the baseline to the lowest
-    // grid coordinate used to place an outline point. Always a
-    // negative value.
+    // The bounds of the type metric.
+    Geometry bounds(void) const;
+
+    // The distance in pixels from the baseline to the lowest grid coordinate
+    // used to place an outline point. Always a negative value.
     double descent(void) const;
 
     // Maximum horizontal advance in pixels.
     double maxHorizontalAdvance(void) const;
 
+    // The origin.
+    Coordinate origin(void) const;
+
+    // The number of pixels per em.
+    Coordinate pixelsPerEm(void) const;
+
     // Text height in pixels.
     double textHeight(void) const;
 
