@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://imagemagick.org/script/license.php                               %
+%    https://imagemagick.org/license/                                         %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -512,6 +512,9 @@ MagickExport Image *CombineImages(const Image *image,
   MagickOffsetType
     progress;
 
+  size_t
+    number_channels;
+
   ssize_t
     y;
 
@@ -539,26 +542,33 @@ MagickExport Image *CombineImages(const Image *image,
       (void) SetImageColorspace(combine_image,RGBColorspace,exception);
     else
       (void) SetImageColorspace(combine_image,sRGBColorspace,exception);
+  number_channels=GetImageListLength(image);
   switch (combine_image->colorspace)
   {
     case UndefinedColorspace:
     case sRGBColorspace:
     {
-      if (GetImageListLength(image) > 3)
+      if (number_channels > 3)
         combine_image->alpha_trait=BlendPixelTrait;
+      if (number_channels > 4)
+        SetPixelMetaChannels(combine_image,number_channels-4,exception);
       break;
     }
     case LinearGRAYColorspace:
     case GRAYColorspace:
     {
-      if (GetImageListLength(image) > 1)
+      if (number_channels > 1)
         combine_image->alpha_trait=BlendPixelTrait;
+      if (number_channels > 2)
+        SetPixelMetaChannels(combine_image,number_channels-2,exception);
       break;
     }
     case CMYKColorspace:
     {
-      if (GetImageListLength(image) > 4)
+      if (number_channels > 4)
         combine_image->alpha_trait=BlendPixelTrait;
+      if (number_channels > 5)
+        SetPixelMetaChannels(combine_image,number_channels-5,exception);
       break;
     }
     default:
@@ -622,7 +632,7 @@ MagickExport Image *CombineImages(const Image *image,
       {
         if (x < (ssize_t) next->columns)
           {
-            q[i]=GetPixelIntensity(next,p);
+            q[i]=(Quantum) GetPixelIntensity(next,p);
             p+=(ptrdiff_t) GetPixelChannels(next);
           }
         q+=(ptrdiff_t) GetPixelChannels(combine_image);
@@ -935,7 +945,7 @@ static inline void FlattenPixelInfo(const Image *image,const PixelInfo *p,
   Sa=QuantumScale*alpha;
   Da=QuantumScale*beta,
   gamma=Sa*(-Da)+Sa+Da;
-  gamma=PerceptibleReciprocal(gamma);
+  gamma=MagickSafeReciprocal(gamma);
   for (i=0; i < (ssize_t) GetPixelChannels(image); i++)
   {
     PixelChannel channel = GetPixelChannelChannel(image,i);
@@ -1165,7 +1175,7 @@ MagickExport MagickBooleanType SetImageAlphaChannel(Image *image,
             i;
 
           Sa=QuantumScale*(double) GetPixelAlpha(image,q);
-          gamma=PerceptibleReciprocal(Sa);
+          gamma=MagickSafeReciprocal(Sa);
           for (i=0; i < (ssize_t) GetPixelChannels(image); i++)
           {
             PixelChannel channel = GetPixelChannelChannel(image,i);
