@@ -5,7 +5,7 @@
   You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
 
-    https://imagemagick.org/script/license.php
+    https://imagemagick.org/license/
 
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
@@ -46,6 +46,8 @@ extern "C" {
 #define MagickPHI    1.61803398874989484820458683436563811772030917980576
 #define MagickPI2    1.57079632679489661923132169163975144209858469968755
 #define MagickPI     3.1415926535897932384626433832795028841971693993751058209749445923078164062
+#define MAGICK_PTRDIFF_MAX  (PTRDIFF_MAX)
+#define MAGICK_PTRDIFF_MIN  (-PTRDIFF_MAX-1)
 #define MagickSQ1_2  0.70710678118654752440084436210484903928483593768847
 #define MagickSQ2    1.41421356237309504880168872420969807856967187537695
 #define MagickSQ2PI  2.50662827463100024161235523934010416269302368164062
@@ -67,24 +69,52 @@ extern "C" {
 #define UndefinedCompressionQuality  0UL
 #define UndefinedTicksPerSecond  100L
 
-static inline QuantumAny CastDoubleToQuantumAny(const double x)
+static inline ptrdiff_t CastDoubleToPtrdiffT(const double x)
 {
+  double
+    value;
+
   if (IsNaN(x) != 0)
     {
       errno=ERANGE;
       return(0);
     }
-  if (x > ((double) ((QuantumAny) ~0)))
+  value=(x < 0.0) ? ceil(x) : floor(x);
+  if (value < ((double) MAGICK_PTRDIFF_MIN))
+    {
+      errno=ERANGE;
+      return(MAGICK_PTRDIFF_MIN);
+    }
+  if (value > ((double) MAGICK_PTRDIFF_MAX))
+    {
+      errno=ERANGE;
+      return(MAGICK_PTRDIFF_MAX);
+    }
+  return((ptrdiff_t) value);
+}
+
+static inline QuantumAny CastDoubleToQuantumAny(const double x)
+{
+  double
+    value;
+
+  if (IsNaN(x) != 0)
+    {
+      errno=ERANGE;
+      return(0);
+    }
+  value=(x < 0.0) ? ceil(x) : floor(x);
+  if (value < 0.0)
+    {
+      errno=ERANGE;
+      return(0);
+    }
+  if (value > ((double) ((QuantumAny) ~0)))
     {
       errno=ERANGE;
       return((QuantumAny) ~0);
     }
-  if (x < 0.0)
-    {
-      errno=ERANGE;
-      return((QuantumAny) 0);
-    }
-  return((QuantumAny) (x+0.5));
+  return((QuantumAny) value);
 }
 
 static inline size_t CastDoubleToSizeT(const double x)
@@ -97,17 +127,17 @@ static inline size_t CastDoubleToSizeT(const double x)
       errno=ERANGE;
       return(0);
     }
-  value=floor(x);
-  if (value >= ((double) MAGICK_SIZE_MAX))
-    {
-      errno=ERANGE;
-      return((size_t) MAGICK_SIZE_MAX);
-    }
+  value=(x < 0.0) ? ceil(x) : floor(x);
   if (value < 0.0)
     {
       errno=ERANGE;
       return(0);
     }
+  if (value > ((double) MAGICK_SIZE_MAX))
+    {
+      errno=ERANGE;
+      return(MAGICK_SIZE_MAX);
+    }
   return((size_t) value);
 }
 
@@ -121,23 +151,16 @@ static inline ssize_t CastDoubleToSsizeT(const double x)
       errno=ERANGE;
       return(0);
     }
-  if (x < 0.0)
+  value=(x < 0.0) ? ceil(x) : floor(x);
+  if (value < ((double) MAGICK_SSIZE_MIN))
     {
-      value=ceil(x);
-      if (value < ((double) MAGICK_SSIZE_MIN))
-        {
-          errno=ERANGE;
-          return((ssize_t) MAGICK_SSIZE_MIN);
-        }
+      errno=ERANGE;
+      return(MAGICK_SSIZE_MIN);
     }
-  else
+  if (value > ((double) MAGICK_SSIZE_MAX))
     {
-      value=floor(x);
-      if (value > ((double) MAGICK_SSIZE_MAX))
-        {
-          errno=ERANGE;
-          return((ssize_t) MAGICK_SSIZE_MAX);
-        }
+      errno=ERANGE;
+      return(MAGICK_SSIZE_MAX);
     }
   return((ssize_t) value);
 }
@@ -152,17 +175,17 @@ static inline unsigned int CastDoubleToUInt(const double x)
       errno=ERANGE;
       return(0);
     }
-  value=floor(x);
-  if (value >= ((double) MAGICK_UINT_MAX))
-    {
-      errno=ERANGE;
-      return((unsigned int) MAGICK_UINT_MAX);
-    }
+  value=(x < 0.0) ? ceil(x) : floor(x);
   if (value < 0.0)
     {
       errno=ERANGE;
       return(0);
     }
+  if (value > ((double) MAGICK_UINT_MAX))
+    {
+      errno=ERANGE;
+      return(MAGICK_UINT_MAX);
+    }
   return((unsigned int) value);
 }
 
@@ -176,17 +199,17 @@ static inline unsigned short CastDoubleToUShort(const double x)
       errno=ERANGE;
       return(0);
     }
-  value=floor(x);
-  if (value >= ((double) MAGICK_USHORT_MAX))
-    {
-      errno=ERANGE;
-      return((unsigned short) MAGICK_USHORT_MAX);
-    }
+  value=(x < 0.0) ? ceil(x) : floor(x);
   if (value < 0.0)
     {
       errno=ERANGE;
       return(0);
     }
+  if (value > ((double) MAGICK_USHORT_MAX))
+    {
+      errno=ERANGE;
+      return(MAGICK_USHORT_MAX);
+    }
   return((unsigned short) value);
 }
 
