@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://imagemagick.org/script/license.php                               %
+%    https://imagemagick.org/license/                                         %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -78,11 +78,14 @@ typedef void *ModuleHandle;
   Define declarations.
 */
 #if defined(MAGICKCORE_LTDL_DELEGATE)
+#  define FilterGlobExpression "*.la"
 #  define ModuleGlobExpression "*.la"
 #else
 #  if defined(_DEBUG)
+#    define FilterGlobExpression "FILTER_DB_*.dll"
 #    define ModuleGlobExpression "IM_MOD_DB_*.dll"
 #  else
+#    define FilterGlobExpression "FILTER_RL_*.dll"
 #    define ModuleGlobExpression "IM_MOD_RL_*.dll"
 #  endif
 #endif
@@ -454,7 +457,10 @@ MagickExport char **GetModuleList(const char *pattern,
   while ((MagickReadDirectory(directory,buffer,&entry) == 0) &&
          (entry != (struct dirent *) NULL))
   {
-    status=GlobExpression(entry->d_name,ModuleGlobExpression,MagickFalse);
+    if (type == MagickImageFilterModule)
+      status=GlobExpression(entry->d_name,FilterGlobExpression,MagickFalse);
+    else
+      status=GlobExpression(entry->d_name,ModuleGlobExpression,MagickFalse);
     if (status == MagickFalse)
       continue;
     if (GlobExpression(entry->d_name,pattern,MagickFalse) == MagickFalse)
@@ -479,6 +485,11 @@ MagickExport char **GetModuleList(const char *pattern,
         (void) CopyMagickString(modules[i],modules[i]+10,MagickPathExtent);
         modules[i][strlen(modules[i])-1]='\0';
       }
+    else if (LocaleNCompare("FILTER_",modules[i],7) == 0)
+      {
+        (void) CopyMagickString(modules[i],modules[i]+10,MagickPathExtent);
+        modules[i][strlen(modules[i])-1]='\0';
+      }
     i++;
   }
   buffer=(struct dirent *) RelinquishMagickMemory(buffer);
@@ -844,7 +855,7 @@ static MagickBooleanType GetMagickModulePath(const char *filename,
 %
 %  The format of the IsModuleTreeInstantiated() method is:
 %
-%      IsModuleTreeInstantiated()
+%      MagickBooleanType IsModuleTreeInstantiated(void)
 %
 */
 
@@ -1525,7 +1536,11 @@ static void TagToFilterModuleName(const char *tag,char *name)
   if (IsEventLogging() != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",tag);
 #if defined(MAGICKCORE_WINDOWS_SUPPORT)
-  (void) FormatLocaleString(name,MagickPathExtent,"FILTER_%s_.dll",tag);
+#if defined(_DEBUG)
+ (void) FormatLocaleString(name,MagickPathExtent,"FILTER_DB_%s_.dll",tag);
+#else
+ (void) FormatLocaleString(name,MagickPathExtent,"FILTER_RL_%s_.dll",tag);
+#endif
 #elif !defined(MAGICKCORE_LTDL_DELEGATE)
   (void) FormatLocaleString(name,MagickPathExtent,"%s.dll",tag);
 #else
@@ -1549,7 +1564,7 @@ static void TagToFilterModuleName(const char *tag,char *name)
 %
 %  The format of the TagToModuleName module is:
 %
-%      TagToModuleName(const char *tag,const char *format,char *module)
+%      void TagToModuleName(const char *tag,const char *format,char *module)
 %
 %  A description of each parameter follows:
 %
