@@ -22,7 +22,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://imagemagick.org/script/license.php                               %
+%    https://imagemagick.org/license/                                         %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -114,7 +114,7 @@ static MagickBooleanType InsertRow(Image *image,ssize_t bpp,unsigned char *p,
         {
           for (bit=0; bit < 8; bit++)
           {
-            index=((*p) & (0x80 >> bit) ? 0x01 : 0x00);
+            index=(Quantum) ((*p) & (0x80 >> bit) ? 0x01 : 0x00);
             SetPixelIndex(image,index,q);
             if (index < image->colors)
               SetPixelViaPixelInfo(image,image->colormap+(ssize_t) index,q);
@@ -126,7 +126,7 @@ static MagickBooleanType InsertRow(Image *image,ssize_t bpp,unsigned char *p,
           {
             for (bit=0; bit < (ssize_t) (image->columns % 8); bit++)
             {
-              index=((*p) & (0x80 >> bit) ? 0x01 : 0x00);
+              index=(Quantum) ((*p) & (0x80 >> bit) ? 0x01 : 0x00);
               SetPixelIndex(image,index,q);
               if (index < image->colors)
                 SetPixelViaPixelInfo(image,image->colormap+(ssize_t) index,q);
@@ -141,22 +141,22 @@ static MagickBooleanType InsertRow(Image *image,ssize_t bpp,unsigned char *p,
       {
         for (x=0; x < ((ssize_t) image->columns-3); x+=4)
         {
-            index=ConstrainColormapIndex(image,(*p >> 6) & 0x3,exception);
+            index=(Quantum) ConstrainColormapIndex(image,(*p >> 6) & 0x3,exception);
             SetPixelIndex(image,index,q);
             if (index < image->colors)
               SetPixelViaPixelInfo(image,image->colormap+(ssize_t) index,q);
             q+=(ptrdiff_t) GetPixelChannels(image);
-            index=ConstrainColormapIndex(image,(*p >> 4) & 0x3,exception);
+            index=(Quantum) ConstrainColormapIndex(image,(*p >> 4) & 0x3,exception);
             SetPixelIndex(image,index,q);
             if (index < image->colors)
               SetPixelViaPixelInfo(image,image->colormap+(ssize_t) index,q);
             q+=(ptrdiff_t) GetPixelChannels(image);
-            index=ConstrainColormapIndex(image,(*p >> 2) & 0x3,exception);
+            index=(Quantum) ConstrainColormapIndex(image,(*p >> 2) & 0x3,exception);
             SetPixelIndex(image,index,q);
             if (index < image->colors)
               SetPixelViaPixelInfo(image,image->colormap+(ssize_t) index,q);
             q+=(ptrdiff_t) GetPixelChannels(image);
-            index=ConstrainColormapIndex(image,(*p) & 0x3,exception);
+            index=(Quantum) ConstrainColormapIndex(image,(*p) & 0x3,exception);
             SetPixelIndex(image,index,q);
             if (index < image->colors)
               SetPixelViaPixelInfo(image,image->colormap+(ssize_t) index,q);
@@ -165,21 +165,21 @@ static MagickBooleanType InsertRow(Image *image,ssize_t bpp,unsigned char *p,
         }
        if ((image->columns % 4) != 0)
           {
-            index=ConstrainColormapIndex(image,(*p >> 6) & 0x3,exception);
+            index=(Quantum) ConstrainColormapIndex(image,(*p >> 6) & 0x3,exception);
             SetPixelIndex(image,index,q);
             if (index < image->colors)
               SetPixelViaPixelInfo(image,image->colormap+(ssize_t) index,q);
             q+=(ptrdiff_t) GetPixelChannels(image);
             if ((image->columns % 4) > 1)
               {
-                index=ConstrainColormapIndex(image,(*p >> 4) & 0x3,exception);
+                index=(Quantum) ConstrainColormapIndex(image,(*p >> 4) & 0x3,exception);
                 SetPixelIndex(image,index,q);
                 if (index < image->colors)
                   SetPixelViaPixelInfo(image,image->colormap+(ssize_t) index,q);
                 q+=(ptrdiff_t) GetPixelChannels(image);
                 if ((image->columns % 4) > 2)
                   {
-                    index=ConstrainColormapIndex(image,(*p >> 2) & 0x3,
+                    index=(Quantum) ConstrainColormapIndex(image,(*p >> 2) & 0x3,
                       exception);
                     SetPixelIndex(image,index,q);
                     if (index < image->colors)
@@ -197,12 +197,12 @@ static MagickBooleanType InsertRow(Image *image,ssize_t bpp,unsigned char *p,
       {
         for (x=0; x < ((ssize_t) image->columns-1); x+=2)
           {
-            index=ConstrainColormapIndex(image,(*p >> 4) & 0x0f,exception);
+            index=(Quantum) ConstrainColormapIndex(image,(*p >> 4) & 0x0f,exception);
             SetPixelIndex(image,index,q);
             if (index < image->colors)
               SetPixelViaPixelInfo(image,image->colormap+(ssize_t) index,q);
             q+=(ptrdiff_t) GetPixelChannels(image);
-            index=ConstrainColormapIndex(image,(*p) & 0x0f,exception);
+            index=(Quantum) ConstrainColormapIndex(image,(*p) & 0x0f,exception);
             SetPixelIndex(image,index,q);
             if (index < image->colors)
               SetPixelViaPixelInfo(image,image->colormap+(ssize_t) index,q);
@@ -211,7 +211,7 @@ static MagickBooleanType InsertRow(Image *image,ssize_t bpp,unsigned char *p,
           }
         if ((image->columns % 2) != 0)
           {
-            index=ConstrainColormapIndex(image,(*p >> 4) & 0x0f,exception);
+            index=(Quantum) ConstrainColormapIndex(image,(*p >> 4) & 0x0f,exception);
             SetPixelIndex(image,index,q);
             if (index < image->colors)
               SetPixelViaPixelInfo(image,image->colormap+(ssize_t) index,q);
@@ -224,7 +224,7 @@ static MagickBooleanType InsertRow(Image *image,ssize_t bpp,unsigned char *p,
       {
         for (x=0; x < (ssize_t) image->columns; x++)
           {
-            index=ConstrainColormapIndex(image,*p,exception);
+            index=(Quantum) ConstrainColormapIndex(image,*p,exception);
             SetPixelIndex(image,index,q);
             if (index < image->colors)
               SetPixelViaPixelInfo(image,image->colormap+(ssize_t) index,q);
