@@ -24,7 +24,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://imagemagick.org/script/license.php                               %
+%    https://imagemagick.org/license/                                         %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -504,9 +504,8 @@ static Image *ReadEMFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (image->units == PixelsPerCentimeterResolution)
             x_resolution*=CENTIMETERS_INCH;
         }
-      image->rows=(size_t) ((height/1000.0/CENTIMETERS_INCH)*y_resolution+0.5);
-      image->columns=(size_t) ((width/1000.0/CENTIMETERS_INCH)*
-        x_resolution+0.5);
+      image->rows=CastDoubleToSizeT((height/1000.0/CENTIMETERS_INCH)*y_resolution+0.5);
+      image->columns=CastDoubleToSizeT((width/1000.0/CENTIMETERS_INCH)*x_resolution+0.5);
     }
   if (image_info->size != (char *) NULL)
     {
@@ -539,10 +538,9 @@ static Image *ReadEMFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           flags=ParseMetaGeometry(geometry,&sans,&sans,&image->columns,
             &image->rows);
           if (image->resolution.x != 0.0)
-            image->columns=(size_t) floor((image->columns*image->resolution.x)+
-              0.5);
+            image->columns=CastDoubleToSizeT(floor((image->columns*image->resolution.x)+0.5));
           if (image->resolution.y != 0.0)
-            image->rows=(size_t) floor((image->rows*image->resolution.y)+0.5);
+            image->rows=CastDoubleToSizeT(floor((image->rows*image->resolution.y)+0.5));
         }
       else
         {
@@ -550,11 +548,11 @@ static Image *ReadEMFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           flags=ParseMetaGeometry(geometry,&sans,&sans,&image->columns,
             &image->rows);
           if (image->resolution.x != 0.0)
-            image->columns=(size_t) floor(((image->columns*image->resolution.x)/
-              DefaultResolution)+0.5);
+            image->columns=CastDoubleToSizeT(floor(((image->columns*image->resolution.x)/
+              DefaultResolution)+0.5));
           if (image->resolution.y != 0.0)
-            image->rows=(size_t) floor(((image->rows*image->resolution.y)/
-              DefaultResolution)+0.5);
+            image->rows=CastDoubleToSizeT(floor(((image->rows*image->resolution.y)/
+              DefaultResolution)+0.5));
         }
       (void) flags;
       geometry=DestroyString(geometry);
@@ -651,10 +649,10 @@ static inline void EMFSetDimensions(Image * image,Gdiplus::Image *source)
   if ((image->resolution.x <= 0.0) || (image->resolution.y <= 0.0))
     return;
 
-  image->columns=(size_t) floor((Gdiplus::REAL) source->GetWidth()/
-    source->GetHorizontalResolution()*image->resolution.x+0.5);
-  image->rows=(size_t) floor((Gdiplus::REAL) source->GetHeight()/
-    source->GetVerticalResolution()*image->resolution.y+0.5);
+  image->columns=CastDoubleToSizeT(floor((Gdiplus::REAL) source->GetWidth()/
+    source->GetHorizontalResolution()*image->resolution.x+0.5));
+  image->rows=CastDoubleToSizeT(floor((Gdiplus::REAL) source->GetHeight()/
+    source->GetVerticalResolution()*image->resolution.y+0.5));
 }
 
 static Image *ReadEMFImage(const ImageInfo *image_info,
@@ -778,10 +776,10 @@ static Image *ReadEMFImage(const ImageInfo *image_info,
   graphics->SetSmoothingMode(Gdiplus::SmoothingModeHighQuality);
   graphics->SetTextRenderingHint(Gdiplus::TextRenderingHintClearTypeGridFit);
   graphics->Clear(Gdiplus::Color((BYTE) ScaleQuantumToChar(
-    image->background_color.alpha),(BYTE) ScaleQuantumToChar(
-    image->background_color.red),(BYTE) ScaleQuantumToChar(
-    image->background_color.green),(BYTE) ScaleQuantumToChar(
-    image->background_color.blue)));
+    (Quantum) image->background_color.alpha),(BYTE) ScaleQuantumToChar(
+    (Quantum) image->background_color.red),(BYTE) ScaleQuantumToChar(
+    (Quantum) image->background_color.green),(BYTE) ScaleQuantumToChar(
+    (Quantum) image->background_color.blue)));
   graphics->DrawImage(source,0,0,(INT) image->columns,(INT) image->rows);
   delete graphics;
   delete source;
