@@ -24,7 +24,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://imagemagick.org/script/license.php                               %
+%    https://imagemagick.org/license/                                         %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -212,7 +212,7 @@ static ssize_t WriteURLComponent(Image *image,const int c)
   
   html5=isalnum(c) != 0 || (c == '-') || (c == '_') || (c == '.') ||
     (c == '!') || (c == '~') || (c == '*') || (c == '\'') || (c == '(') ||
-    (c == ')') ?  c : 0;
+    (c == ')') ?  (char) c : 0;
   if (html5 != 0)
     (void) FormatLocaleString(encoding,MagickPathExtent,"%c",html5);
   else
