@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://imagemagick.org/script/license.php                               %
+%    https://imagemagick.org/license/                                         %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -41,6 +41,7 @@
 */
 #include "MagickCore/studio.h"
 #include "MagickCore/artifact.h"
+#include "MagickCore/attribute.h"
 #include "MagickCore/blob.h"
 #include "MagickCore/blob-private.h"
 #include "MagickCore/cache.h"
@@ -243,7 +244,7 @@ static Image *Read1XImage(Image *image,ExceptionInfo *exception)
           Quantum
             index;
 
-          index=((byte & (0x80 >> bit)) != 0 ? (i == 0 ? 0x01 : 0x02) : 0x00);
+          index=(Quantum) ((byte & (0x80 >> bit)) != 0 ? (i == 0 ? 0x01 : 0x02) : 0x00);
           if (i == 0)
             SetPixelIndex(image,index,q);
           else
@@ -561,8 +562,8 @@ static Image *ReadICONImage(const ImageInfo *image_info,
                 byte=(size_t) ReadBlobByte(image);
                 for (bit=0; bit < 8; bit++)
                 {
-                  SetPixelIndex(image,((byte & (0x80 >> bit)) != 0 ? 0x01 :
-                    0x00),q);
+                  SetPixelIndex(image,(Quantum) ((byte & (0x80 >> bit)) != 0 ?
+                    0x01 : 0x00),q);
                   q+=(ptrdiff_t) GetPixelChannels(image);
                 }
               }
@@ -571,8 +572,8 @@ static Image *ReadICONImage(const ImageInfo *image_info,
                   byte=(size_t) ReadBlobByte(image);
                   for (bit=0; bit < (image->columns % 8); bit++)
                   {
-                    SetPixelIndex(image,((byte & (0x80 >> bit)) != 0 ? 0x01 :
-                      0x00),q);
+                    SetPixelIndex(image,(Quantum) ((byte & (0x80 >> bit)) != 0 ?
+                      0x01 : 0x00),q);
                     q+=(ptrdiff_t) GetPixelChannels(image);
                   }
                 }
@@ -603,15 +604,15 @@ static Image *ReadICONImage(const ImageInfo *image_info,
               for (x=0; x < ((ssize_t) image->columns-1); x+=2)
               {
                 byte=(size_t) ReadBlobByte(image);
-                SetPixelIndex(image,((byte >> 4) & 0xf),q);
+                SetPixelIndex(image,(Quantum) ((byte >> 4) & 0xf),q);
                 q+=(ptrdiff_t) GetPixelChannels(image);
-                SetPixelIndex(image,((byte) & 0xf),q);
+                SetPixelIndex(image,(Quantum) ((byte) & 0xf),q);
                 q+=(ptrdiff_t) GetPixelChannels(image);
               }
               if ((image->columns % 2) != 0)
                 {
                   byte=(size_t) ReadBlobByte(image);
-                  SetPixelIndex(image,((byte >> 4) & 0xf),q);
+                  SetPixelIndex(image,(Quantum) ((byte >> 4) & 0xf),q);
                   q+=(ptrdiff_t) GetPixelChannels(image);
                 }
               for (x=0; x < (ssize_t) scanline_pad; x++)
@@ -850,6 +851,13 @@ ModuleExport size_t RegisterICONImage(void)
   entry->flags|=CoderDecoderSeekableStreamFlag;
   entry->flags|=CoderEncoderSeekableStreamFlag;
   (void) RegisterMagickInfo(entry);
+  entry=AcquireMagickInfo("ICON","ICN","Microsoft icon");
+  entry->decoder=(DecodeImageHandler *) ReadICONImage;
+  entry->encoder=(EncodeImageHandler *) WriteICONImage;
+  entry->flags ^= CoderAdjoinFlag;
+  entry->flags|=CoderDecoderSeekableStreamFlag;
+  entry->flags|=CoderEncoderSeekableStreamFlag;
+  (void) RegisterMagickInfo(entry);
   entry=AcquireMagickInfo("ICON","ICON","Microsoft icon");
   entry->decoder=(DecodeImageHandler *) ReadICONImage;
   entry->encoder=(EncodeImageHandler *) WriteICONImage;
@@ -923,7 +931,7 @@ ModuleExport void UnregisterICONImage(void)
 static Image *AutoResizeImage(const Image *image,const char *option,
   MagickOffsetType *count,ExceptionInfo *exception)
 {
-#define MAX_SIZES 11
+#define MAX_SIZES 16
 
   char
     *q;
@@ -936,7 +944,7 @@ static Image *AutoResizeImage(const Image *image,const char *option,
     *resized;
 
   size_t
-    sizes[MAX_SIZES] = { 512, 256, 192, 128, 96, 64, 48, 40, 32, 24, 16 };
+    sizes[MAX_SIZES] = { 256, 192, 128, 96, 64, 48, 40, 32, 24, 16 };
 
   ssize_t
     i;
@@ -961,7 +969,7 @@ static Image *AutoResizeImage(const Image *image,const char *option,
       p++;
   }
   if (i == 0)
-    i=MAX_SIZES;
+    i=10; /* the number of sizes when they are not specified by the user */
   *count=i;
   for (i=0; i < *count; i++)
   {
@@ -1115,17 +1123,16 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
             return(MagickFalse);
           }
         write_info=CloneImageInfo(image_info);
-        (void) CopyMagickString(write_info->magick,"PNG32",MagickPathExtent);
         length=0;
         /*
-          Don't write any ancillary chunks except for gAMA.
+          Don't write any ancillary chunks except for gAMA,tRNS.
         */
-        (void) SetImageArtifact(write_image,"png:include-chunk","none,gama");
+        (void) SetImageArtifact(write_image,"png:include-chunk",
+          "none,gama,tRNS");
         /*
           Only write PNG32 formatted PNG (32-bit RGBA), 8 bits per channel.
         */
-        (void) SetImageArtifact(write_image,"png:IHDR.color-type-orig","6");
-        (void) SetImageArtifact(write_image,"png:IHDR.bit-depth-orig","8");
+        (void) CopyMagickString(write_info->magick,"PNG32",MagickPathExtent);
         png=(unsigned char *) ImageToBlob(write_info,write_image,&length,
           exception);
         write_image=DestroyImageList(write_image);
@@ -1410,10 +1417,10 @@ static MagickBooleanType WriteICONImage(const ImageInfo *image_info,
             q=icon_colormap;
             for (i=0; i < (ssize_t) next->colors; i++)
             {
-              *q++=ScaleQuantumToChar(next->colormap[i].blue);
-              *q++=ScaleQuantumToChar(next->colormap[i].green);
-              *q++=ScaleQuantumToChar(next->colormap[i].red);
-              *q++=(unsigned char) 0x0;
+              *q++=ScaleQuantumToChar((Quantum) next->colormap[i].blue);
+              *q++=ScaleQuantumToChar((Quantum) next->colormap[i].green);
+              *q++=ScaleQuantumToChar((Quantum) next->colormap[i].red);
+              *q++=(unsigned char) 0x00;
             }
             for ( ; i < (ssize_t) 1UL << bits_per_pixel; i++)
             {
