@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://imagemagick.org/script/license.php                               %
+%    https://imagemagick.org/license/                                         %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -151,7 +151,7 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
     return(DestroyImageList(image));
   (void) SetImageProperty(image,"label",label,exception);
   draw_info=CloneDrawInfo(image_info,(DrawInfo *) NULL);
-  width=CastDoubleToUnsigned(0.5*draw_info->pointsize*strlen(label)+0.5);
+  width=CastDoubleToSizeT(0.5*draw_info->pointsize*strlen(label)+0.5);
   if (AcquireMagickResource(WidthResource,width) == MagickFalse)
     {
       label=DestroyString(label);
@@ -164,8 +164,10 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
   AdjustTypeMetricBounds(&metrics);
   if ((image->columns == 0) && (image->rows == 0))
     {
-      image->columns=(size_t) floor(metrics.width+draw_info->stroke_width+0.5);
-      image->rows=(size_t) floor(metrics.height+draw_info->stroke_width+0.5);
+      image->columns=CastDoubleToSizeT(floor(metrics.width+
+        draw_info->stroke_width+0.5));
+      image->rows=CastDoubleToSizeT(floor(metrics.height+
+        draw_info->stroke_width+0.5));
     }
   else
     if ((status != MagickFalse) && (strlen(label) > 0) &&
@@ -214,11 +216,10 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
               if (status == MagickFalse)
                 break;
               AdjustTypeMetricBounds(&metrics);
-              width=CastDoubleToUnsigned(metrics.width+draw_info->stroke_width+
+              width=CastDoubleToSizeT(metrics.width+draw_info->stroke_width+
                 0.5);
-              height=CastDoubleToUnsigned(
-                metrics.height-metrics.underline_position+
-                draw_info->stroke_width+0.5);
+              height=CastDoubleToSizeT(metrics.height-
+                metrics.underline_position+draw_info->stroke_width+0.5);
               if ((image->columns != 0) && (image->rows != 0))
                 {
                   if ((width > image->columns) && (height > image->rows))
@@ -251,8 +252,8 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
           if (status == MagickFalse)
             break;
           AdjustTypeMetricBounds(&metrics);
-          width=CastDoubleToUnsigned(metrics.width+draw_info->stroke_width+0.5);
-          height=CastDoubleToUnsigned(metrics.height-metrics.underline_position+
+          width=CastDoubleToSizeT(metrics.width+draw_info->stroke_width+0.5);
+          height=CastDoubleToSizeT(metrics.height-metrics.underline_position+
             draw_info->stroke_width+0.5);
           if ((image->columns != 0) && (image->rows != 0))
             {
@@ -284,15 +285,17 @@ static Image *ReadLABELImage(const ImageInfo *image_info,
   status=GetMultilineTypeMetrics(image,draw_info,&metrics,exception);
   AdjustTypeMetricBounds(&metrics);
   if (image->columns == 0)
-    image->columns=(size_t) floor(metrics.width+draw_info->stroke_width+0.5);
+    image->columns=CastDoubleToSizeT(floor(metrics.width+
+      draw_info->stroke_width+0.5));
   if (image->columns == 0)
-    image->columns=(size_t) floor(draw_info->pointsize+draw_info->stroke_width+
-      0.5);
+    image->columns=CastDoubleToSizeT(floor(draw_info->pointsize+
+      draw_info->stroke_width+0.5));
   if (image->rows == 0)
-    image->rows=(size_t) floor(metrics.height+draw_info->stroke_width+0.5);
+    image->rows=CastDoubleToSizeT(floor(metrics.height+
+      draw_info->stroke_width+0.5));
   if (image->rows == 0)
-    image->rows=(size_t) floor(draw_info->pointsize+draw_info->stroke_width+
-      0.5);
+    image->rows=CastDoubleToSizeT(floor(draw_info->pointsize+
+      draw_info->stroke_width+0.5));
   status=SetImageExtent(image,image->columns,image->rows,exception);
   if (status == MagickFalse)
     {
