@@ -23,7 +23,7 @@
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://imagemagick.org/script/license.php                               %
+%    https://imagemagick.org/license/                                         %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -940,6 +940,7 @@ static MagickBooleanType EncodeImageAttributes(Image *image,FILE *file,
 
   double
     elapsed_time,
+    scale,
     user_time,
     version;
 
@@ -951,8 +952,7 @@ static MagickBooleanType EncodeImageAttributes(Image *image,FILE *file,
 
   size_t
     depth,
-    distance,
-    scale;
+    distance;
 
   ssize_t
     i,
@@ -1130,7 +1130,6 @@ static MagickBooleanType EncodeImageAttributes(Image *image,FILE *file,
   channel_moments=(ChannelMoments *) NULL;
   channel_phash=(ChannelPerceptualHash *) NULL;
   channel_features=(ChannelFeatures *) NULL;
-  scale=1;
   channel_statistics=GetImageStatistics(image,exception);
   if (channel_statistics == (ChannelStatistics *) NULL)
     return(MagickFalse);
@@ -1192,10 +1191,10 @@ static MagickBooleanType EncodeImageAttributes(Image *image,FILE *file,
     }
   }
   (void) FormatLocaleFile(file,"    \n");
-  scale=1;
+  scale=1.0;
   if (image->depth <= MAGICKCORE_QUANTUM_DEPTH)
-    scale=QuantumRange/((size_t) QuantumRange >> ((size_t)
-      MAGICKCORE_QUANTUM_DEPTH-image->depth));
+    scale=(double) (QuantumRange/((size_t) QuantumRange >> ((size_t)
+      MAGICKCORE_QUANTUM_DEPTH-image->depth)));
   if (channel_statistics != (ChannelStatistics *) NULL)
     {
       (void) FormatLocaleFile(file,"    pixels: %.20g\n",
